import { useState, useEffect } from 'react';
import { Table } from 'antd';

export default function AppList(props) {
  const { remote = {}, filters = [], ...reset } = props;
  const [data, setData] = useState({ total: 0, list: [] });
  const [page, setPage] = useState({ current: 1, pageSize: 10 });

  // 分页配置
  const pagination = {
    total: 100,
    showSizeChanger: true,
    showQuickJumper: true,
    showTotal: (total) => `共${total}条数据`,
    onChange: handlePageChange,
  };

  // 获取列表数据
  async function fetchList() {
    let { httpRequest, beforeRequest, callback, params } = remote;
    if (!httpRequest) return;
    if (beforeRequest) {
      params = beforeRequest(params);
    }
    const res = await httpRequest(params);
    const { list = [], total = 0 } = callback ? callback(res.data, params) : res.data || {};
    setData({ list, total });
  }

  // 筛选
  async function handleSearch() {
    setPage({ ...page, current: 1 });
    await fetchList();
  }
  // 重置
  async function handleReset() {
    // 清空筛选条件
    setPage({ ...page, current: 1 });
    await fetchList();
  }
  // 刷新
  async function handleRefresh() {
    await fetchList();
  }
  // 分页改变
  async function handlePageChange(current, pageSize) {
    setPage({ current, pageSize });
    await handleRefresh();
  }

  // useEffect(async () => {
  //   const res = await fetchList(remote);
  //   setDataSource(res.data.list || []);
  // }, []);

  return <Table bordered dataSource={data.list} pagination={pagination} {...reset}></Table>;
}
